package java.text;

import sun.text.bidi.BidiBase;

public final class Bidi
{
    public static final int DIRECTION_LEFT_TO_RIGHT = 0;
    public static final int DIRECTION_RIGHT_TO_LEFT = 1;
    public static final int DIRECTION_DEFAULT_LEFT_TO_RIGHT = -2;
    public static final int DIRECTION_DEFAULT_RIGHT_TO_LEFT = -1;
    private BidiBase bidiBase;
    
    public Bidi(String s, int n) {
        if (s == null) {
            throw new IllegalArgumentException("paragraph is null");
        }
        this.bidiBase = new BidiBase(s.toCharArray(), 0, null, 0, s.length(), n);
        return;
    }
    
    public Bidi(AttributedCharacterIterator para) {
        if (para == null) {
            throw new IllegalArgumentException("paragraph is null");
        }
        (this.bidiBase = new BidiBase(0, 0)).setPara(para);
        return;
    }
    
    public Bidi(char[] array, int i, byte[] array2, int j, int k, int n) {
        if (array == null) {
            throw new IllegalArgumentException("text is null");
        }
        if (k < 0) {
            throw new IllegalArgumentException("bad length: " + k);
        }
        if (i < 0 || k > array.length - i) {
            throw new IllegalArgumentException("bad range: " + i + " length: " + k + " for text of length: " + array.length);
        }
        if (array2 != null && (j < 0 || k > array2.length - j)) {
            throw new IllegalArgumentException("bad range: " + j + " length: " + k + " for embeddings of length: " + array.length);
        }
        this.bidiBase = new BidiBase(array, i, array2, j, k, n);
        return;
    }
    
    public Bidi createLineBidi(int n, int n2) {
        Bidi bidi = new Bidi(new AttributedString("").getIterator());
        return this.bidiBase.setLine(this, this.bidiBase, bidi, bidi.bidiBase, n, n2);
    }
    
    public boolean isMixed() {
        return this.bidiBase.isMixed();
    }
    
    public boolean isLeftToRight() {
        return this.bidiBase.isLeftToRight();
    }
    
    public boolean isRightToLeft() {
        return this.bidiBase.isRightToLeft();
    }
    
    public int getLength() {
        return this.bidiBase.getLength();
    }
    
    public boolean baseIsLeftToRight() {
        return this.bidiBase.baseIsLeftToRight();
    }
    
    public int getBaseLevel() {
        return this.bidiBase.getParaLevel();
    }
    
    public int getLevelAt(int n) {
        return this.bidiBase.getLevelAt(n);
    }
    
    public int getRunCount() {
        return this.bidiBase.countRuns();
    }
    
    public int getRunLevel(int n) {
        return this.bidiBase.getRunLevel(n);
    }
    
    public int getRunStart(int n) {
        return this.bidiBase.getRunStart(n);
    }
    
    public int getRunLimit(int n) {
        return this.bidiBase.getRunLimit(n);
    }
    
    public static boolean requiresBidi(char[] array, int n, int n2) {
        return BidiBase.requiresBidi(array, n, n2);
    }
    
    public static void reorderVisually(byte[] array, int n, Object[] array2, int n2, int n3) {
        BidiBase.reorderVisually(array, n, array2, n2, n3);
    }
    
    @Override
    public String toString() {
        return this.bidiBase.toString();
    }
}
